==> itext-src-1.4.5.tar.gz: com/lowagie/tools/plugins/treeview/FileTreeNode.java <==
/*
 * $Id: FileTreeNode.java,v 1.4 2006/08/21 09:52:41 blowagie Exp $
 * $Name:  $
 *
 * Copyright 2005 by Carsten Hammer.
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the License.
 *
 * The Original Code is 'iText, a free JAVA-PDF library'.
 *
 * The Initial Developer of the Original Code is Bruno Lowagie. Portions created by
 * the Initial Developer are Copyright (C) 1999, 2000, 2001, 2002 by Bruno Lowagie.
 * All Rights Reserved.
 * Co-Developer of the code is Paulo Soares. Portions created by the Co-Developer
 * are Copyright (C) 2000, 2001, 2002 by Paulo Soares. All Rights Reserved.
 *
 * Contributor(s): all the names of the contributors are added in the source code
 * where applicable.
 *
 * Alternatively, the contents of this file may be used under the terms of the
 * LGPL license (the "GNU LIBRARY GENERAL PUBLIC LICENSE"), in which case the
 * provisions of LGPL are applicable instead of those above.  If you wish to
 * allow use of your version of this file only under the terms of the LGPL
 * License and not to allow others to use your version of this file under
 * the MPL, indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by the LGPL.
 * If you do not delete the provisions above, a recipient may use your version
 * of this file under either the MPL or the GNU LIBRARY GENERAL PUBLIC LICENSE.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the MPL as stated above or under the terms of the GNU
 * Library General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Library general Public License for more
 * details.
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://www.lowagie.com/iText/
 */

package com.lowagie.tools.plugins.treeview;

import com.lowagie.text.pdf.*;
import javax.swing.Icon;
import javax.swing.ImageIcon;

public class FileTreeNode extends UpdateableTreeNode {

	private static final long serialVersionUID = -4678195579970838801L;

	PdfReader reader;

	public FileTreeNode(Object p0, PdfReader reader) {
		super(p0, true);
		this.reader = reader;
	}

	public void updateview(IUpdatenodeview updateobject) {
		StringBuffer sb = new StringBuffer();
		sb.append("<html>");
		sb.append("<p>");
		sb.append(this.userObject);
		sb.append("</p>");
		sb.append("<p>");
		sb.append("PDF Version 1." + this.reader.getPdfVersion());
		sb.append("</p>");
		sb.append("<p>");
		sb.append("Number of Pages: " + this.reader.getNumberOfPages());
		sb.append("</p>");
		sb.append("</html>");
		updateobject.showvalues(sb.toString());
	}

	public Icon getIcon() {
		return new ImageIcon(TreeViewInternalFrame.class
				.getResource("icon16.gif"));
	}

}

==> itext-src-1.4.8.tar.gz: com/lowagie/tools/plugins/treeview/FileTreeNode.java <==
/*
 * $Id: FileTreeNode.java,v 1.6 2006/09/15 23:37:38 xlv Exp $
 * $Name:  $
 *
 * Copyright 2005 by Carsten Hammer.
 *
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the License.
 *
 * The Original Code is 'iText, a free JAVA-PDF library'.
 *
 * The Initial Developer of the Original Code is Bruno Lowagie. Portions created by
 * the Initial Developer are Copyright (C) 1999, 2000, 2001, 2002 by Bruno Lowagie.
 * All Rights Reserved.
 * Co-Developer of the code is Paulo Soares. Portions created by the Co-Developer
 * are Copyright (C) 2000, 2001, 2002 by Paulo Soares. All Rights Reserved.
 *
 * Contributor(s): all the names of the contributors are added in the source code
 * where applicable.
 *
 * Alternatively, the contents of this file may be used under the terms of the
 * LGPL license (the "GNU LIBRARY GENERAL PUBLIC LICENSE"), in which case the
 * provisions of LGPL are applicable instead of those above.  If you wish to
 * allow use of your version of this file only under the terms of the LGPL
 * License and not to allow others to use your version of this file under
 * the MPL, indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by the LGPL.
 * If you do not delete the provisions above, a recipient may use your version
 * of this file under either the MPL or the GNU LIBRARY GENERAL PUBLIC LICENSE.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the MPL as stated above or under the terms of the GNU
 * Library General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Library general Public License for more
 * details.
 *
 * If you didn't download this code from the following link, you should check if
 * you aren't using an obsolete version:
 * http://www.lowagie.com/iText/
 */

package com.lowagie.tools.plugins.treeview;

import javax.swing.Icon;
import javax.swing.ImageIcon;

import com.lowagie.text.pdf.PdfReader;

public class FileTreeNode extends UpdateableTreeNode {

	private static final long serialVersionUID = -4678195579970838801L;

	PdfReader reader;

	public FileTreeNode(Object p0, PdfReader reader) {
		super(p0, true);
		this.reader = reader;
	}

	public void updateview(IUpdatenodeview updateobject) {
		StringBuffer sb = new StringBuffer();
		sb.append("<html>");
		sb.append("<p>");
		sb.append(this.userObject);
		sb.append("</p>");
		sb.append("<p>");
		sb.append("PDF Version 1.").append(this.reader.getPdfVersion());
		sb.append("</p>");
		sb.append("<p>");
		sb.append("Number of Pages: ").append(this.reader.getNumberOfPages());
		sb.append("</p>");
		sb.append("</html>");
		updateobject.showvalues(sb.toString());
	}

	public Icon getIcon() {
		return new ImageIcon(TreeViewInternalFrame.class
				.getResource("icon16.gif"));
	}

}
